pub struct UndoScheduler<'w, E: Event + Clone> { /* private fields */ }Implementations
Sourceimpl<'w, E: Event + Clone> UndoScheduler<'w, E>
impl<'w, E: Event + Clone> UndoScheduler<'w, E>
Sourcepub fn register(&mut self, event: E)
pub fn register(&mut self, event: E)
Register the undo-event in the registered area.
Events can registered multiple, and when UndoRequester::undo is called,
last registered will sent
Sourcepub fn reserve(&mut self, event: E)
pub fn reserve(&mut self, event: E)
Place the undo-event in the reserved area.
Events is in placed on same reserved area until reserve_commit is called.
This method is useful when want to sent multiple undo-event with single call UndoRequest::undo .
Sourcepub fn register_all_reserved(&mut self)
pub fn register_all_reserved(&mut self)
Moves all events placed on the reserved area by reserve to the registered area.
Sourceimpl<'w, E: Event + Clone + Default> UndoScheduler<'w, E>
impl<'w, E: Event + Clone + Default> UndoScheduler<'w, E>
Sourcepub fn register_default(&mut self)
pub fn register_default(&mut self)
Register the undo-event in the registered area with default value.
Events can registered multiple, and when UndoRequester::undo is called,
last registered will sent
Sourcepub fn reserve_default(&mut self)
pub fn reserve_default(&mut self)
Place the undo-event in the reserved area with default value.
Events is in placed on same reserved area until reserve_commit is called.
This method is useful when want to sent multiple undo-event with single call UndoRequest::undo .